library(testthat)
library(fy)
library(data.table)
setDTthreads(1)

test_check("fy")
